@@ -48,7 +48,7 @@ class MultipleRequestHandler(tornado.web.RequestHandler):
     def get(self):
         app = self.application
         try:
-            keys = ujson.loads(self.request.body)
+            keys = self.get_arguments("key")
             result = []
             for key in keys:
                 try:
